氏名

日 本 花 子

昭和61年 5月 1日生

住所<br>東京都千代田区霞が関2\-1\-2

交付<br>令和01年05月07日 12345

# 2024年\(令和06年\)06月01日まで有効

眼鏡等<br>免許の

条件等

<img src="figures/in_gallery5_p1_figure_0.png" width="200px"><br>
見 本

第 012345678900 号

番号 

二小小豆

他

平成15年04月01日

平成17年06月01日

平成29年08月01日<br>二種

|種 類||中型|||大特|||
|-|-|-|-|-|-|-|-|
|||原府||中|音三|大宜三大特三||

 

大型小特

運転免許証

<img src="figures/in_gallery5_p1_figure_1.png" width="200px"><br>
公安委員会
